@@ -1,8 +1,10 @@
+import os
 import itertools
 import time
 import copy
 import random
 import functools
+import platform
 from unittest import mock
 
 import pytest
@@ -12,6 +14,11 @@ from jaraco.functools import Throttler, method_cache, retry_call, retry
 
 
 class TestThrottler:
+    @pytest.mark.xfail(
+        os.environ.get('GITHUB_ACTIONS')  # type: ignore
+        and platform.system() == 'Darwin',
+        reason="Performance is heavily throttled on Github Actions Mac runs",
+    )
     def test_function_throttled(self):
         """
         Ensure the throttler actually throttles calls.
